pub fn parse_request(input: &str) -> Result<JsonRpcIncoming, McpError>Expand description
Parse a JSON string into a JSON-RPC incoming request.
This is a convenience function for parsing incoming messages.
pub fn parse_request(input: &str) -> Result<JsonRpcIncoming, McpError>Parse a JSON string into a JSON-RPC incoming request.
This is a convenience function for parsing incoming messages.