pub struct ConnectionCounter { /* private fields */ }Expand description
Connection counter for tracking active connections.
This is designed to be wrapped in Arc and shared across async tasks.
Use try_acquire_arc to get a guard that can be moved into spawned tasks.
Implementations
Sourceimpl ConnectionCounter
impl ConnectionCounter
Sourcepub fn try_acquire_arc(self: &Arc<Self>) -> Option<ConnectionGuard>
pub fn try_acquire_arc(self: &Arc<Self>) -> Option<ConnectionGuard>
Try to acquire a connection slot (for use when counter is in Arc).
Returns a guard that releases the slot when dropped, or None if at capacity.
The guard is Send + 'static and can be moved into spawned async tasks.