pub struct ProtocolConfig {
pub preferred_version: ProtocolVersion,
pub supported_versions: Vec<ProtocolVersion>,
pub allow_fallback: bool,
}Expand description
Protocol version configuration.
Fields
preferred_version: ProtocolVersionPreferred protocol version.
supported_versions: Vec<ProtocolVersion>Supported protocol versions.
allow_fallback: boolAllow fallback to server’s preferred version if client’s is unsupported.
Implementations
Sourceimpl ProtocolConfig
impl ProtocolConfig
Sourcepub fn strict(version: impl Into<ProtocolVersion>) -> Self
pub fn strict(version: impl Into<ProtocolVersion>) -> Self
Create a strict configuration that only accepts the specified version.
Sourcepub fn multi_version() -> Self
pub fn multi_version() -> Self
Create a multi-version configuration that accepts all stable versions.
The preferred version is the latest stable. Older clients are accepted and responses are filtered through the appropriate version adapter.
Sourcepub fn is_supported(&self, version: &ProtocolVersion) -> bool
pub fn is_supported(&self, version: &ProtocolVersion) -> bool
Check if a protocol version is supported.